@@ -1,8 +1,9 @@
 import pathlib
 from typing import Literal, Optional, Sequence, Union
 
-from ..types import StrOrBytesPath, StrOrPath
-from .core import run
+from libvcs._internal.run import run
+
+from ..types import StrOrBytesPath, StrPath
 
 _CMD = Union[StrOrBytesPath, Sequence[StrOrBytesPath]]
 
@@ -11,7 +12,7 @@ RevisionLiteral = Union[Literal["HEAD", "BASE", "COMMITTED", "PREV"], None]
 
 
 class Svn:
-    def __init__(self, dir: StrOrPath):
+    def __init__(self, *, dir: StrPath):
         """Lite, typed, pythonic wrapper for svn(1).
 
         Parameters
@@ -37,6 +38,7 @@ class Svn:
     def run(
         self,
         args: _CMD,
+        *,
         quiet: Optional[bool] = None,
         username: Optional[str] = None,
         password: Optional[str] = None,
@@ -80,7 +82,7 @@ class Svn:
         Examples
         --------
         >>> svn = Svn(dir=tmp_path)
-        >>> svn.run(['help'])  # doctest: +NORMALIZE_WHITESPACE
+        >>> svn.run(['help'])
         "usage: svn <subcommand> [options] [args]..."
         """
 
@@ -107,10 +109,11 @@ class Svn:
         if config_option is not None:
             cli_args.extend(["--config-option", str(config_option)])
 
-        return run(cmd=cli_args, **kwargs)
+        return run(args=cli_args, **kwargs)
 
     def checkout(
         self,
+        *,
         url: str,
         revision: Union[RevisionLiteral, str] = None,
         force: Optional[bool] = None,
@@ -158,6 +161,7 @@ class Svn:
 
     def add(
         self,
+        *,
         path: Union[list[pathlib.Path], pathlib.Path],
         targets: Optional[pathlib.Path] = None,
         depth: DepthLiteral = None,
@@ -174,7 +178,7 @@ class Svn:
 
         Parameters
         ----------
-        targets : pathlib.path
+        targets : pathlib.Path
             `--targets ARG`: contents of file ARG as additional args
         depth :
             `--depth ARG`, Sparse checkout support, Optional
@@ -224,7 +228,6 @@ class Svn:
         self,
         remove: Optional[str] = None,
         show_passwords: Optional[bool] = None,
-        *args,
         **kwargs,
     ):
         """
@@ -243,7 +246,7 @@ class Svn:
         >>> Svn(dir=tmp_path).auth()
         "Credentials cache in '...' is empty"
         """
-        local_flags: list[str] = [*args]
+        local_flags: list[str] = []
 
         if remove is not None:
             local_flags.extend(["--remove", remove])
@@ -254,7 +257,8 @@ class Svn:
 
     def blame(
         self,
-        target: pathlib.Path,
+        target: StrOrBytesPath,
+        *,
         revision: Union[RevisionLiteral, str] = None,
         verbose: Optional[bool] = None,
         force: Optional[bool] = None,
@@ -262,7 +266,6 @@ class Svn:
         incremental: Optional[bool] = None,
         xml: Optional[bool] = None,
         extensions: Optional[str] = None,
-        *args,
         **kwargs,
     ):
         """
@@ -303,7 +306,7 @@ class Svn:
         >>> svn.blame('new.txt')
         '1        ... example text'
         """
-        local_flags: list[str] = [target, *args]
+        local_flags: list[str] = [str(target)]
 
         if revision is not None:
             local_flags.append(f"--revision={revision}")
@@ -360,6 +363,7 @@ class Svn:
 
     def commit(
         self,
+        *,
         path: Union[list[pathlib.Path], pathlib.Path],
         targets: Optional[pathlib.Path] = None,
         message: Optional[str] = None,
@@ -370,7 +374,6 @@ class Svn:
         force_log: Optional[bool] = None,
         keep_changelists: Optional[bool] = None,
         include_externals: Optional[bool] = None,
-        *args,
         **kwargs,
     ):
         """
